import dayjs from 'dayjs'
export const handleCall = (phone: string) => {
  uni.makePhoneCall({ phoneNumber: phone })
}
export const isImageOrVideo = (url) => {
  const ext = url.split('.').pop().toLowerCase()
  if (['jpg', 'jpeg', 'png', 'gif', 'bmp', 'webp'].includes(ext)) {
    return 'image'
  } else if (['mp4', 'avi', 'mov', 'mkv', 'webm', 'flv'].includes(ext)) {
    return 'video'
  } else {
    return 'unknown'
  }
}
export const requestToast = async <T>(
  func: () => Promise<IResData<T>>,
  options: { error?: boolean; errorTitle?: string; success?: boolean; successTitle?: string } = {
    error: true,
  },
) => {
  const { code, data, msg } = await func()
  if (code === 0 && options.success) {
    uni.showToast({
      title: options.successTitle,
      icon: 'none',
    })
  }
  if (code !== 0 && options.error) {
    uni.showToast({
      title: options.errorTitle || msg,
      icon: 'none',
    })
  }
  return { code, data, msg }
}

export const getActivityStatus = (startAt: string | number, endAt: string | number) => {
  const now = new Date()
  if (dayjs(now).isBefore(dayjs(startAt))) {
    return 'waiting'
  } else if (dayjs(now).isAfter(dayjs(startAt)) && dayjs(now).isBefore(dayjs(endAt))) {
    return 'running'
  } else {
    return 'overdue'
  }
}
export const getActivityStatusText = (startAt: string | number, endAt: string | number) =>
  ({ running: '报名中', waiting: '未开始', overdue: '已结束' })[getActivityStatus(startAt, endAt)]
export const getActivityStatusButtonText = (startAt: string | number, endAt: string | number) =>
  ({ running: '立即报名', waiting: '查看详情', overdue: '查看详情' })[
    getActivityStatus(startAt, endAt)
  ]
